@@ -17,6 +17,7 @@ from paloma_sdk.util.url import urljoin
 from .api.auth import AsyncAuthAPI, AuthAPI
 from .api.authz import AsyncAuthzAPI, AuthzAPI
 from .api.bank import AsyncBankAPI, BankAPI
+from .api.cw20 import AsyncCw20API, Cw20API
 from .api.distribution import AsyncDistributionAPI, DistributionAPI
 from .api.feegrant import AsyncFeeGrantAPI, FeeGrantAPI
 from .api.gov import AsyncGovAPI, GovAPI
@@ -34,7 +35,7 @@ from .wallet import AsyncWallet, Wallet
 
 
 def get_default(chain_id: str) -> [Coins, Numeric]:
-    return [Coins.from_str("0.15uluna"), Numeric.parse(1.75)]
+    return [Coins.from_str("0.15ugrain"), Numeric.parse(1.75)]
 
 class AsyncLCDClient:
     def __init__(
@@ -64,6 +65,7 @@ class AsyncLCDClient:
 
         self.auth = AsyncAuthAPI(self)
         self.bank = AsyncBankAPI(self)
+        self.cw20 = AsyncCw20API(self)
         self.distribution = AsyncDistributionAPI(self)
         self.feegrant = AsyncFeeGrantAPI(self)
         self.gov = AsyncGovAPI(self)
@@ -195,6 +197,9 @@ class LCDClient(AsyncLCDClient):
     bank: BankAPI
     """:class:`BankAPI<paloma_sdk.client.lcd.api.bank.BankAPI>`."""
 
+    cw20: Cw20API
+    """:class:`Cw20API<paloma_sdk.client.lcd.api.bank.Cw20API>`."""
+
     distribution: DistributionAPI
     """:class:`DistributionAPI<paloma_sdk.client.lcd.api.distribution.DistributionAPI>`."""
 
@@ -249,6 +254,7 @@ class LCDClient(AsyncLCDClient):
 
         self.auth = AuthAPI(self)
         self.bank = BankAPI(self)
+        self.cw20 = Cw20API(self)
         self.distribution = DistributionAPI(self)
         self.gov = GovAPI(self)
         self.feegrant = FeeGrantAPI(self)
